@@ -11,15 +11,14 @@
 #
 ###############################################################################
 from __future__ import print_function
-import math
 import numpy
 from scipy import interpolate
 from .actionAngleAdiabatic import actionAngleAdiabatic
 from .actionAngle import actionAngle, UnboundError
-import galpy.potential
-from galpy.potential.Potential import _evaluatePotentials
-from galpy.potential.Potential import flatten as flatten_potential
-from galpy.util import multi
+from .. import potential
+from ..potential.Potential import _evaluatePotentials
+from ..potential.Potential import flatten as flatten_potential
+from ..util import multi
 _PRINTOUTSIDEGRID= False
 class actionAngleAdiabaticGrid(actionAngle):
     """Action-angle formalism for axisymmetric potentials using the adiabatic approximation, grid-based interpolation"""
@@ -99,7 +98,7 @@ class actionAngleAdiabaticGrid(actionAngle):
         else:
             if numcores > 1:
                 jz= multi.parallel_map((lambda x: self._aA(thisRs[x],0.,1.,#these two r dummies
-                                                              0.,math.sqrt(2.*thisy[x]*thisEzZmaxs[x]),
+                                                              0.,numpy.sqrt(2.*thisy[x]*thisEzZmaxs[x]),
                                                            _justjz=True,
                                                            **kwargs)[2]),
                                        range(nR*nEz),numcores=numcores)
@@ -126,12 +125,11 @@ class actionAngleAdiabaticGrid(actionAngle):
         self._Lzmin= 0.01
         self._Lzs= numpy.linspace(self._Lzmin,
                                   self._Rmax\
-                                      *galpy.potential.vcirc(self._pot,
-                                                             self._Rmax),
+                                      *potential.vcirc(self._pot,self._Rmax),
                                   nLz)
         self._Lzmax= self._Lzs[-1]
         #Calculate ER(vr=0,R=RL)
-        self._RL= numpy.array([galpy.potential.rl(self._pot,l) for l in self._Lzs])
+        self._RL= numpy.array([potential.rl(self._pot,l) for l in self._Lzs])
         self._RLInterp= interpolate.InterpolatedUnivariateSpline(self._Lzs,
                                                                  self._RL,k=3)
         self._ERRL= _evaluatePotentials(self._pot,self._RL,numpy.zeros(nLz)) +self._Lzs**2./2./self._RL**2.
@@ -262,7 +260,7 @@ class actionAngleAdiabaticGrid(actionAngle):
                 if _PRINTOUTSIDEGRID: #pragma: no cover
                     print("Outside of grid in Ez", R > self._Rmax , R < self._Rmin , (Ez != 0 and numpy.log(Ez) > thisEzZmax))
                 jz= self._aA(R,0.,1.,#these two r dummies
-                             0.,math.sqrt(2.*Ez),
+                             0.,numpy.sqrt(2.*Ez),
                              _justjz=True,
                              **kwargs)[2]
             else:
@@ -353,7 +351,7 @@ class actionAngleAdiabaticGrid(actionAngle):
             if _PRINTOUTSIDEGRID: #pragma: no cover
                 print("Outside of grid in Ez")
             jz= self._aA(self._eval_R,0.,1.,#these two r dummies
-                         0.,math.sqrt(2.*Ez),
+                         0.,numpy.sqrt(2.*Ez),
                          _justjz=True,
                          **kwargs)[2]
         else:
