@@ -13,14 +13,6 @@ extern "C" {
 #include <gsl/gsl_roots.h>
 #include <gsl/gsl_spline.h>
 #include "interp_2d.h"
-#ifdef _WIN32
-// On Windows, *need* to define this function to allow the package to be imported
-#if PY_MAJOR_VERSION >= 3
-  PyMODINIT_FUNC PyInit_galpy_actionAngle_c(void); // Python 3
-#else
-  PyMODINIT_FUNC initgalpy_actionAngle_c(void); // Python 2
-#endif
-#endif
 /*
   Macro for dealing with potentially unused variables due to OpenMP
  */
