@@ -11,9 +11,9 @@ void parse_leapFuncArgs_Full(int, struct potentialArg *,int **,double **);
 #ifdef _WIN32
 // On Windows, *need* to define this function to allow the package to be imported
 #if PY_MAJOR_VERSION >= 3
-  PyMODINIT_FUNC PyInit_galpy_integrate_c(void); // Python 3
+  PyMODINIT_FUNC PyInit_libgalpy(void); // Python 3
 #else
-  PyMODINIT_FUNC initgalpy_integrate_c(void); // Python 2
+  PyMODINIT_FUNC initlibgalpy(void); // Python 2
 #endif
 #endif
 //OpenMP
