@@ -8,11 +8,11 @@
 #                            with m^2 = x^2+y^2/b^2+z^2/c^2
 #
 ###############################################################################
-import numpy
 import hashlib
+import numpy
 from scipy import integrate
-from galpy.util import bovy_coords
-from galpy.util import _rotate_to_arbitrary_vector
+from ..util import bovy_coords
+from ..util import _rotate_to_arbitrary_vector
 from .Potential import Potential, _APY_LOADED, \
     check_potential_inputs_not_arrays
 if _APY_LOADED:
