@@ -6,17 +6,12 @@
 #
 #  Phi(r, phi, z) = -4*pi*G*H*rho0*exp(-(r-r0)/Rs)*sum(Cn/(Kn*Dn)*cos(n*gamma)*sech(Kn*z/Bn)^Bn)
 ###############################################################################
-
 from __future__ import division
 from .Potential import Potential, _APY_LOADED
-from galpy.util import bovy_conversion
-import numpy as np
-
+from ..util import bovy_conversion
+import numpy
 if _APY_LOADED:
     from astropy import units
-
-
-
 class SpiralArmsPotential(Potential):
     """Class that implements the spiral arms potential from (`Cox and Gomez 2002 <https://arxiv.org/abs/astro-ph/0207635>`__). Should be used to modulate an existing potential (density is positive in the arms, negative outside).
     
@@ -90,16 +85,16 @@ class SpiralArmsPotential(Potential):
 
         self._N = -N  # trick to flip to left handed coordinate system; flips sign for phi and phi_ref, but also alpha.
         self._alpha = -alpha  # we don't want sign for alpha to change, so flip alpha. (see eqn. 3 in the paper)
-        self._sin_alpha = np.sin(-alpha)
-        self._tan_alpha = np.tan(-alpha)
+        self._sin_alpha = numpy.sin(-alpha)
+        self._tan_alpha = numpy.tan(-alpha)
         self._r_ref = r_ref
         self._phi_ref = phi_ref
         self._Rs = Rs
         self._H = H
-        self._Cs = self._Cs0 = np.array(Cs)
-        self._ns = self._ns0 = np.arange(1, len(Cs) + 1)
+        self._Cs = self._Cs0 = numpy.array(Cs)
+        self._ns = self._ns0 = numpy.arange(1, len(Cs) + 1)
         self._omega = omega
-        self._rho0 = 1 / (4 * np.pi)
+        self._rho0 = 1 / (4 * numpy.pi)
         self._HNn = self._HNn0 = self._H * self._N * self._ns0
 
         self.isNonAxi = True   # Potential is not axisymmetric
@@ -123,11 +118,11 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-05-12  Jack Hong (UBC)
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
@@ -137,8 +132,8 @@ class SpiralArmsPotential(Potential):
         Bs = self._B(R)
         Ds = self._D(R)
 
-        return -self._H * np.exp(-(R-self._r_ref) / self._Rs) \
-               * np.sum(self._Cs / Ks / Ds * np.cos(self._ns * self._gamma(R, phi - self._omega * t)) / np.cosh(Ks * z / Bs) ** Bs,axis=0)
+        return -self._H * numpy.exp(-(R-self._r_ref) / self._Rs) \
+               * numpy.sum(self._Cs / Ks / Ds * numpy.cos(self._ns * self._gamma(R, phi - self._omega * t)) / numpy.cosh(Ks * z / Bs) ** Bs,axis=0)
 
     
     def _Rforce(self, R, z, phi=0, t=0):
@@ -157,17 +152,17 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-05-12  Jack Hong (UBC)
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
             self._HNn=self._HNn0
 
-        He = self._H * np.exp(-(R-self._r_ref)/self._Rs)
+        He = self._H * numpy.exp(-(R-self._r_ref)/self._Rs)
 
         Ks = self._K(R)
         Bs = self._B(R)
@@ -180,15 +175,15 @@ class SpiralArmsPotential(Potential):
         g = self._gamma(R, phi - self._omega * t)
         dg_dR = self._dgamma_dR(R)
 
-        cos_ng = np.cos(self._ns * g)
-        sin_ng = np.sin(self._ns * g)
+        cos_ng = numpy.cos(self._ns * g)
+        sin_ng = numpy.sin(self._ns * g)
 
         zKB = z * Ks / Bs
-        sechzKB = 1 / np.cosh(zKB)
+        sechzKB = 1 / numpy.cosh(zKB)
 
-        return -He * np.sum(self._Cs * sechzKB**Bs / Ds * ((self._ns * dg_dR / Ks * sin_ng
-                                                            + cos_ng * (z * np.tanh(zKB) * (dKs_dR/Ks - dBs_dR/Bs)
-                                                                        - dBs_dR / Ks * np.log(sechzKB)
+        return -He * numpy.sum(self._Cs * sechzKB**Bs / Ds * ((self._ns * dg_dR / Ks * sin_ng
+                                                            + cos_ng * (z * numpy.tanh(zKB) * (dKs_dR/Ks - dBs_dR/Bs)
+                                                                        - dBs_dR / Ks * numpy.log(sechzKB)
                                                                         + dKs_dR / Ks**2
                                                                         + dDs_dR / Ds / Ks))
                                                            + cos_ng / Ks / self._Rs),axis=0)
@@ -210,11 +205,11 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-05-25  Jack Hong (UBC) 
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
@@ -225,9 +220,9 @@ class SpiralArmsPotential(Potential):
         Ds = self._D(R)
         zK_B = z * Ks / Bs
 
-        return -self._H * np.exp(-(R-self._r_ref) / self._Rs) \
-               * np.sum(self._Cs / Ds * np.cos(self._ns * self._gamma(R, phi - self._omega * t))
-                        * np.tanh(zK_B) / np.cosh(zK_B)**Bs,axis=0)
+        return -self._H * numpy.exp(-(R-self._r_ref) / self._Rs) \
+               * numpy.sum(self._Cs / Ds * numpy.cos(self._ns * self._gamma(R, phi - self._omega * t))
+                        * numpy.tanh(zK_B) / numpy.cosh(zK_B)**Bs,axis=0)
 
     
     def _phiforce(self, R, z, phi=0, t=0):
@@ -246,11 +241,11 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-05-25  Jack Hong (UBC)
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
@@ -261,8 +256,8 @@ class SpiralArmsPotential(Potential):
         Bs = self._B(R)
         Ds = self._D(R)
 
-        return -self._H * np.exp(-(R-self._r_ref) / self._Rs) \
-               * np.sum(self._N * self._ns * self._Cs / Ds / Ks / np.cosh(z * Ks / Bs)**Bs * np.sin(self._ns * g),axis=0)
+        return -self._H * numpy.exp(-(R-self._r_ref) / self._Rs) \
+               * numpy.sum(self._N * self._ns * self._Cs / Ds / Ks / numpy.cosh(z * Ks / Bs)**Bs * numpy.sin(self._ns * g),axis=0)
 
     
     def _R2deriv(self, R, z, phi=0, t=0):
@@ -282,18 +277,18 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-05-31  Jack Hong (UBC)
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
             self._HNn=self._HNn0
 
         Rs = self._Rs
-        He = self._H * np.exp(-(R-self._r_ref)/self._Rs)
+        He = self._H * numpy.exp(-(R-self._r_ref)/self._Rs)
 
         Ks = self._K(R)
         Bs = self._B(R)
@@ -320,17 +315,17 @@ class SpiralArmsPotential(Potential):
         dg_dR = self._dgamma_dR(R)
         d2g_dR2 = self._N / R**2 / self._tan_alpha
 
-        sin_ng = np.sin(self._ns * g)
-        cos_ng = np.cos(self._ns * g)
+        sin_ng = numpy.sin(self._ns * g)
+        cos_ng = numpy.cos(self._ns * g)
 
         zKB = z * Ks / Bs
-        sechzKB = 1 / np.cosh(zKB)
+        sechzKB = 1 / numpy.cosh(zKB)
         sechzKB_Bs = sechzKB**Bs
-        log_sechzKB = np.log(sechzKB)
-        tanhzKB = np.tanh(zKB)
+        log_sechzKB = numpy.log(sechzKB)
+        tanhzKB = numpy.tanh(zKB)
         ztanhzKB = z * tanhzKB
 
-        return -He / Rs * (np.sum(self._Cs * sechzKB_Bs / Ds
+        return -He / Rs * (numpy.sum(self._Cs * sechzKB_Bs / Ds
                                   * ((self._ns * dg_dR / Ks * sin_ng
                                       + cos_ng * (ztanhzKB * (dKs_dR/Ks - dBs_dR/Bs)
                                                   - dBs_dR / Ks * log_sechzKB
@@ -381,11 +376,11 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-05-26  Jack Hong (UBC) 
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
@@ -396,10 +391,10 @@ class SpiralArmsPotential(Potential):
         Bs = self._B(R)
         Ds = self._D(R)
         zKB = z * Ks / Bs
-        tanh2_zKB = np.tanh(zKB)**2
+        tanh2_zKB = numpy.tanh(zKB)**2
 
-        return -self._H * np.exp(-(R-self._r_ref)/self._Rs) \
-               * np.sum(self._Cs * Ks / Ds * ((tanh2_zKB - 1) / Bs + tanh2_zKB) * np.cos(self._ns * g) / np.cosh(zKB)**Bs,axis=0)
+        return -self._H * numpy.exp(-(R-self._r_ref)/self._Rs) \
+               * numpy.sum(self._Cs * Ks / Ds * ((tanh2_zKB - 1) / Bs + tanh2_zKB) * numpy.cos(self._ns * g) / numpy.cosh(zKB)**Bs,axis=0)
 
     
     def _phi2deriv(self, R, z, phi=0, t=0):
@@ -419,11 +414,11 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-05-29 Jack Hong (UBC)
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
@@ -434,8 +429,8 @@ class SpiralArmsPotential(Potential):
         Bs = self._B(R)
         Ds = self._D(R)
 
-        return self._H * np.exp(-(R-self._r_ref) / self._Rs) \
-               * np.sum(self._Cs * self._N**2. * self._ns**2. / Ds / Ks / np.cosh(z*Ks/Bs)**Bs * np.cos(self._ns*g),axis=0)
+        return self._H * numpy.exp(-(R-self._r_ref) / self._Rs) \
+               * numpy.sum(self._Cs * self._N**2. * self._ns**2. / Ds / Ks / numpy.cosh(z*Ks/Bs)**Bs * numpy.cos(self._ns*g),axis=0)
 
     
     def _Rzderiv(self, R, z, phi=0., t=0.):
@@ -455,18 +450,18 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-05-12  Jack Hong (UBC)
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
             self._HNn=self._HNn0
 
         Rs = self._Rs
-        He = self._H * np.exp(-(R-self._r_ref)/self._Rs)
+        He = self._H * numpy.exp(-(R-self._r_ref)/self._Rs)
 
         Ks = self._K(R)
         Bs = self._B(R)
@@ -479,16 +474,16 @@ class SpiralArmsPotential(Potential):
         g = self._gamma(R, phi - self._omega * t)
         dg_dR = self._dgamma_dR(R)
 
-        cos_ng = np.cos(self._ns * g)
-        sin_ng = np.sin(self._ns * g)
+        cos_ng = numpy.cos(self._ns * g)
+        sin_ng = numpy.sin(self._ns * g)
 
         zKB = z * Ks / Bs
-        sechzKB = 1 / np.cosh(zKB)
+        sechzKB = 1 / numpy.cosh(zKB)
         sechzKB_Bs = sechzKB**Bs
-        log_sechzKB = np.log(sechzKB)
-        tanhzKB = np.tanh(zKB)
+        log_sechzKB = numpy.log(sechzKB)
+        tanhzKB = numpy.tanh(zKB)
 
-        return - He * np.sum(sechzKB_Bs * self._Cs / Ds * (Ks * tanhzKB * (self._ns * dg_dR / Ks * sin_ng
+        return - He * numpy.sum(sechzKB_Bs * self._Cs / Ds * (Ks * tanhzKB * (self._ns * dg_dR / Ks * sin_ng
                                                                            + cos_ng * (z * tanhzKB * (dKs_dR/Ks - dBs_dR/Bs)
                                                                                        - dBs_dR / Ks * log_sechzKB
                                                                                        + dKs_dR / Ks**2
@@ -516,17 +511,17 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-06-09  Jack Hong (UBC)
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
             self._HNn=self._HNn0
 
-        He = self._H * np.exp(-(R - self._r_ref) / self._Rs)
+        He = self._H * numpy.exp(-(R - self._r_ref) / self._Rs)
 
         Ks = self._K(R)
         Bs = self._B(R)
@@ -539,16 +534,16 @@ class SpiralArmsPotential(Potential):
         g = self._gamma(R, phi - self._omega * t)
         dg_dR = self._dgamma_dR(R)
 
-        cos_ng = np.cos(self._ns * g)
-        sin_ng = np.sin(self._ns * g)
+        cos_ng = numpy.cos(self._ns * g)
+        sin_ng = numpy.sin(self._ns * g)
         zKB = z * Ks / Bs
-        sechzKB = 1 / np.cosh(zKB)
+        sechzKB = 1 / numpy.cosh(zKB)
         sechzKB_Bs = sechzKB ** Bs
 
-        return - He * np.sum(self._Cs * sechzKB_Bs / Ds * self._ns * self._N
+        return - He * numpy.sum(self._Cs * sechzKB_Bs / Ds * self._ns * self._N
                            * (- self._ns * dg_dR / Ks * cos_ng
-                              + sin_ng * (z * np.tanh(zKB) * (dKs_dR / Ks - dBs_dR / Bs)
-                                          + 1/Ks * (-dBs_dR * np.log(sechzKB)
+                              + sin_ng * (z * numpy.tanh(zKB) * (dKs_dR / Ks - dBs_dR / Bs)
+                                          + 1/Ks * (-dBs_dR * numpy.log(sechzKB)
                                                     + dKs_dR / Ks
                                                     + dDs_dR / Ds
                                                     + 1 / self._Rs))),axis=0)
@@ -571,11 +566,11 @@ class SpiralArmsPotential(Potential):
         HISTORY:
             2017-05-12  Jack Hong (UBC)
         """
-        if isinstance(R,np.ndarray) or isinstance(z,np.ndarray):
-            nR= len(R) if isinstance(R,np.ndarray) else len(z)
-            self._Cs=np.transpose(np.array([self._Cs0,]*nR))
-            self._ns=np.transpose(np.array([self._ns0,]*nR))
-            self._HNn=np.transpose(np.array([self._HNn0,]*nR))
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
         else:
             self._Cs=self._Cs0
             self._ns=self._ns0
@@ -589,9 +584,9 @@ class SpiralArmsPotential(Potential):
 
         ng = self._ns * g
         zKB = z * Ks / Bs
-        sech_zKB = 1 / np.cosh(zKB)
-        tanh_zKB = np.tanh(zKB)
-        log_sech_zKB = np.log(sech_zKB)
+        sech_zKB = 1 / numpy.cosh(zKB)
+        tanh_zKB = numpy.tanh(zKB)
+        log_sech_zKB = numpy.log(sech_zKB)
 
         # numpy of E as defined in the appendix of the paper.
         E = 1 + Ks * self._H / Ds * (1 - 0.3 / (1 + 0.3 * Ks * self._H) ** 2) - R / self._Rs \
@@ -605,10 +600,10 @@ class SpiralArmsPotential(Potential):
              - (0.4 * (Ks * self._H) ** 2 * zKB * sech_zKB) ** 2 / Bs \
              + 1.2 * (Ks * self._H) ** 2 * zKB * tanh_zKB
 
-        return np.sum(self._Cs * self._rho0 * (self._H / (Ds * R)) * np.exp(-(R - self._r_ref) / self._Rs)
-                      * sech_zKB**Bs * (np.cos(ng) * (Ks * R * (Bs + 1) / Bs * sech_zKB**2
+        return numpy.sum(self._Cs * self._rho0 * (self._H / (Ds * R)) * numpy.exp(-(R - self._r_ref) / self._Rs)
+                      * sech_zKB**Bs * (numpy.cos(ng) * (Ks * R * (Bs + 1) / Bs * sech_zKB**2
                                                       - 1 / Ks / R * (E**2 + rE))
-                                        - 2 * np.sin(ng)* E * np.cos(self._alpha)),axis=0)
+                                        - 2 * numpy.sin(ng)* E * numpy.cos(self._alpha)),axis=0)
 
     def OmegaP(self):
         """
@@ -627,7 +622,7 @@ class SpiralArmsPotential(Potential):
 
     def _gamma(self, R, phi):
         """Return gamma. (eqn 3 in the paper)"""
-        return self._N * (phi - self._phi_ref - np.log(R / self._r_ref) / self._tan_alpha)
+        return self._N * (phi - self._phi_ref - numpy.log(R / self._r_ref) / self._tan_alpha)
 
     def _dgamma_dR(self, R):
         """Return the first derivative of gamma wrt R."""
