@@ -7,7 +7,11 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+#include <stdbool.h>
 #include <interp_2d.h>
+#ifndef M_1_PI
+#define M_1_PI 0.31830988618379069122
+#endif
 struct potentialArg{
   double (*potentialEval)(double R, double Z, double phi, double t,
 			  struct potentialArg *);
@@ -35,15 +39,26 @@ struct potentialArg{
 			    struct potentialArg *);
   double (*linearForce)(double x, double t,
 			 struct potentialArg *);
+  double (*dens)(double R, double Z, double phi, double t,
+		 struct potentialArg *);
+  // For forces that require velocity input (e.g., dynam fric)
+  bool requiresVelocity;
+  double (*RforceVelocity)(double R, double Z, double phi, double t,
+			    struct potentialArg *,double,double,double);
+  double (*zforceVelocity)(double R, double Z, double phi, double t,
+			   struct potentialArg *,double,double,double);
+  double (*phiforceVelocity)(double R, double Z, double phi, double t,
+			     struct potentialArg *,double,double,double);
   int nargs;
   double * args;
+  // To allow 1D interpolation for an arbitrary number of splines
+  int nspline1d;
+  gsl_interp_accel ** acc1d;
+  gsl_spline ** spline1d;
+  // 2D interpolation
   interp_2d * i2d;
   gsl_interp_accel * accx;
   gsl_interp_accel * accy;
-  gsl_interp_accel * accz;
-  gsl_spline * xSpline;
-  gsl_spline * ySpline;
-  gsl_spline * zSpline;
   interp_2d * i2drforce;
   gsl_interp_accel * accxrforce;
   gsl_interp_accel * accyrforce;
@@ -65,10 +80,39 @@ void init_potentialArgs(int,struct potentialArg *);
 void free_potentialArgs(int,struct potentialArg *);
 //Potential and force evaluation
 double evaluatePotentials(double,double,int, struct potentialArg *);
-double calcRforce(double,double,double,double,int,struct potentialArg *);
-double calczforce(double,double,double,double,int,struct potentialArg *);
-double calcPhiforce(double, double,double, double, 
-			int, struct potentialArg *);
+// Hack to allow optional velocity for dissipative forces
+// https://stackoverflow.com/a/52610204/10195320
+// Reason to use ##__VA_ARGS__ is that when no optional velocity is supplied,
+// there is a comma left in the argument list and ## absorbs that for gcc/icc
+// MSVC supposedly does this automatically for regular __VA_ARGS__, at least
+// for now, but I can't get this to work locally or on AppVeyor
+// https://docs.microsoft.com/en-us/cpp/preprocessor/preprocessor-experimental-overview?view=vs-2019#comma-elision-in-variadic-macros
+// Therefore, I use an alternative where all arguments are variadic, such
+// that there should always be many. Final subtlety is that we have to define
+// the EXPAND macro to expand the __VA_ARGS__ into multiple arguments,
+// otherwise it's treated as a single argument in the next function call
+// calll (e.g., CALCRFORCE would get R = __VA_ARGS = R,Z,phi,...)
+#ifdef _MSC_VER
+#define EXPAND(x) x
+#define calcRforce(...)   EXPAND(CALCRFORCE(__VA_ARGS__,0.,0.,0.))
+#define calczforce(...)   EXPAND(CALCZFORCE(__VA_ARGS__,0.,0.,0.))
+#define calcPhiforce(...) EXPAND(CALCPHIFORCE(__VA_ARGS__,0.,0.,0.))
+#else
+#define calcRforce(R,Z,phi,t,nargs,potentialArgs,...) CALCRFORCE(R,Z,phi,t,nargs,potentialArgs,##__VA_ARGS__,0.,0.,0.)
+#define calczforce(R,Z,phi,t,nargs,potentialArgs,...) CALCZFORCE(R,Z,phi,t,nargs,potentialArgs,##__VA_ARGS__,0.,0.,0.)
+#define calcPhiforce(R,Z,phi,t,nargs,potentialArgs,...) CALCPHIFORCE(R,Z,phi,t,nargs,potentialArgs,##__VA_ARGS__,0.,0.,0.)
+#endif
+#define CALCRFORCE(R,Z,phi,t,nargs,potentialArgs,vR,vT,vZ,...) calcRforce(R,Z,phi,t,nargs,potentialArgs,vR,vT,vZ)
+#define CALCZFORCE(R,Z,phi,t,nargs,potentialArgs,vR,vT,vZ,...) calczforce(R,Z,phi,t,nargs,potentialArgs,vR,vT,vZ)
+#define CALCPHIFORCE(R,Z,phi,t,nargs,potentialArgs,vR,vT,vZ,...) calcPhiforce(R,Z,phi,t,nargs,potentialArgs,vR,vT,vZ)
+double (calcRforce)(double,double,double,double,int,struct potentialArg *,
+		    double,double,double);
+double (calczforce)(double,double,double,double,int,struct potentialArg *,
+		      double,double,double);
+double (calcPhiforce)(double, double,double, double, 
+		      int, struct potentialArg *,
+		      double,double,double);
+// end hack
 double calcR2deriv(double, double, double,double, 
 			 int, struct potentialArg *);
 double calcphi2deriv(double, double, double,double, 
@@ -86,6 +130,7 @@ double calcPlanarphi2deriv(double, double, double,
 double calcPlanarRphideriv(double, double, double, 
 			   int, struct potentialArg *);
 double calcLinearForce(double, double, int, struct potentialArg *);
+double calcDensity(double, double, double,double, int, struct potentialArg *);
 //ZeroForce
 double ZeroPlanarForce(double,double,double,
 		       struct potentialArg *);
@@ -112,6 +157,8 @@ double LogarithmicHaloPotentialPlanarphi2deriv(double ,double, double,
 					       struct potentialArg *);
 double LogarithmicHaloPotentialPlanarRphideriv(double ,double, double,
 					       struct potentialArg *);
+double LogarithmicHaloPotentialDens(double ,double , double, double,
+				    struct potentialArg *);
 //DehnenBarPotential
 double DehnenBarPotentialRforce(double,double,double,double,
 				struct potentialArg *);
@@ -161,6 +208,8 @@ double MiyamotoNagaiPotentialzforce(double,double,double,double,
 				    struct potentialArg *);
 double MiyamotoNagaiPotentialPlanarR2deriv(double ,double, double,
 					   struct potentialArg *);
+double MiyamotoNagaiPotentialDens(double ,double , double, double,
+				  struct potentialArg *);
 //LopsidedDiskPotential
 double LopsidedDiskPotentialRforce(double,double,double,
 					   struct potentialArg *);
@@ -183,6 +232,8 @@ double PowerSphericalPotentialzforce(double,double,double,double,
 				     struct potentialArg *);
 double PowerSphericalPotentialPlanarR2deriv(double ,double, double,
 					    struct potentialArg *);
+double PowerSphericalPotentialDens(double ,double , double, double,
+				   struct potentialArg *);
 //HernquistPotential
 double HernquistPotentialEval(double ,double , double, double,
 			      struct potentialArg *);
@@ -194,6 +245,8 @@ double HernquistPotentialzforce(double,double,double,double,
 				struct potentialArg *);
 double HernquistPotentialPlanarR2deriv(double ,double, double,
 				       struct potentialArg *);
+double HernquistPotentialDens(double ,double , double, double,
+			      struct potentialArg *);
 //NFWPotential
 double NFWPotentialEval(double ,double , double, double,
 			struct potentialArg *);
@@ -205,6 +258,8 @@ double NFWPotentialzforce(double,double,double,double,
 			  struct potentialArg *);
 double NFWPotentialPlanarR2deriv(double ,double, double,
 				 struct potentialArg *);
+double NFWPotentialDens(double ,double , double, double,
+			 struct potentialArg *);
 //JaffePotential
 double JaffePotentialEval(double ,double , double, double,
 			  struct potentialArg *);
@@ -216,6 +271,8 @@ double JaffePotentialzforce(double,double,double,double,
 			    struct potentialArg *);
 double JaffePotentialPlanarR2deriv(double ,double, double,
 				   struct potentialArg *);
+double JaffePotentialDens(double ,double , double, double,
+			  struct potentialArg *);
 //DoubleExponentialDiskPotential
 double DoubleExponentialDiskPotentialEval(double ,double , double, double,
 					  struct potentialArg *);
@@ -225,6 +282,8 @@ double DoubleExponentialDiskPotentialPlanarRforce(double,double,double,
 						  struct potentialArg *);
 double DoubleExponentialDiskPotentialzforce(double,double, double,double,
 					    struct potentialArg *);
+double DoubleExponentialDiskPotentialDens(double ,double , double, double,
+					  struct potentialArg *);
 //FlattenedPowerPotential
 double FlattenedPowerPotentialEval(double,double,double,double,
 				   struct potentialArg *);
@@ -236,6 +295,8 @@ double FlattenedPowerPotentialzforce(double,double,double,double,
 				     struct potentialArg *);
 double FlattenedPowerPotentialPlanarR2deriv(double,double,double,
 					    struct potentialArg *);
+double FlattenedPowerPotentialDens(double,double,double,double,
+				   struct potentialArg *);
 //interpRZPotential
 double interpRZPotentialEval(double ,double , double, double,
 			     struct potentialArg *);
@@ -254,6 +315,8 @@ double IsochronePotentialzforce(double,double,double,double,
 				struct potentialArg *);
 double IsochronePotentialPlanarR2deriv(double ,double, double,
 				       struct potentialArg *);
+double IsochronePotentialDens(double ,double , double, double,
+			      struct potentialArg *);
 //PowerSphericalPotentialwCutoff
 double PowerSphericalPotentialwCutoffEval(double ,double , double, double,
 					  struct potentialArg *);
@@ -265,6 +328,8 @@ double PowerSphericalPotentialwCutoffzforce(double,double,double,double,
 					    struct potentialArg *);
 double PowerSphericalPotentialwCutoffPlanarR2deriv(double ,double, double,
 						   struct potentialArg *);
+double PowerSphericalPotentialwCutoffDens(double ,double , double, double,
+					  struct potentialArg *);
 //KuzminKutuzovStaeckelPotential
 double KuzminKutuzovStaeckelPotentialEval(double,double,double,double,
                         struct potentialArg *);
@@ -299,6 +364,8 @@ double PlummerPotentialzforce(double,double,double,double,
 				        struct potentialArg *);
 double PlummerPotentialPlanarR2deriv(double,double,double,
 					    struct potentialArg *);
+double PlummerPotentialDens(double,double,double,double,
+			    struct potentialArg *);
 //PseudoIsothermalPotential
 double PseudoIsothermalPotentialEval(double,double,double,double,
 				     struct potentialArg *);
@@ -310,6 +377,8 @@ double PseudoIsothermalPotentialzforce(double,double,double,double,
 				       struct potentialArg *);
 double PseudoIsothermalPotentialPlanarR2deriv(double,double,double,
 					      struct potentialArg *);
+double PseudoIsothermalPotentialDens(double,double,double,double,
+				     struct potentialArg *);
 //BurkertPotential
 double BurkertPotentialEval(double,double,double,double,
 				     struct potentialArg *);
@@ -321,6 +390,8 @@ double BurkertPotentialzforce(double,double,double,double,
 				       struct potentialArg *);
 double BurkertPotentialPlanarR2deriv(double,double,double,
 					      struct potentialArg *);
+double BurkertPotentialDens(double,double,double,double,
+			    struct potentialArg *);
 //EllipsoidalPotential
 double EllipsoidalPotentialEval(double,double,double,double,
 				     struct potentialArg *);
@@ -334,6 +405,8 @@ double EllipsoidalPotentialPlanarphiforce(double,double,double,
 					  struct potentialArg *);
 double EllipsoidalPotentialzforce(double,double,double,double,
 				  struct potentialArg *);
+double EllipsoidalPotentialDens(double,double,double,double,
+				struct potentialArg *);
 //TriaxialHernquistPotential: uses EllipsoidalPotential, only need psi, dens, densDeriv
 double TriaxialHernquistPotentialpsi(double,double *);
 double TriaxialHernquistPotentialmdens(double,double *);
@@ -366,6 +439,8 @@ double SCFPotentialPlanarphi2deriv(double,double,double,
 				        struct potentialArg *);
 double SCFPotentialPlanarRphideriv(double,double,double,
 				        struct potentialArg *);
+double SCFPotentialDens(double,double,double,double,
+			struct potentialArg *);
 //SoftenedNeedleBarPotential
 double SoftenedNeedleBarPotentialEval(double,double,double,double,
 				      struct potentialArg *);
@@ -388,6 +463,8 @@ double DiskSCFPotentialzforce(double,double,double,double,
 				        struct potentialArg *);
 double DiskSCFPotentialPlanarRforce(double,double,double,
 					      struct potentialArg *);
+double DiskSCFPotentialDens(double,double,double,double,
+			    struct potentialArg *);
 
 // SpiralArmsPotential
 double SpiralArmsPotentialEval(double, double, double, double,
@@ -430,6 +507,47 @@ double KGPotentialLinearForce(double,double,struct potentialArg *);
 //IsothermalDiskPotential
 double IsothermalDiskPotentialLinearForce(double,double,struct potentialArg *);
 
+//DehnenSphericalPotential
+double DehnenSphericalPotentialEval(double ,double , double, double,
+			      struct potentialArg *);
+double DehnenSphericalPotentialRforce(double ,double , double, double,
+				struct potentialArg *);
+double DehnenSphericalPotentialPlanarRforce(double ,double, double,
+				      struct potentialArg *);
+double DehnenSphericalPotentialzforce(double,double,double,double,
+				struct potentialArg *);
+double DehnenSphericalPotentialPlanarR2deriv(double ,double, double,
+				       struct potentialArg *);
+double DehnenSphericalPotentialDens(double ,double , double, double,
+			      struct potentialArg *);
+//DehnenCoreSphericalPotential
+double DehnenCoreSphericalPotentialEval(double ,double , double, double,
+			      struct potentialArg *);
+double DehnenCoreSphericalPotentialRforce(double ,double , double, double,
+				struct potentialArg *);
+double DehnenCoreSphericalPotentialPlanarRforce(double ,double, double,
+				      struct potentialArg *);
+double DehnenCoreSphericalPotentialzforce(double,double,double,double,
+				struct potentialArg *);
+double DehnenCoreSphericalPotentialPlanarR2deriv(double ,double, double,
+				       struct potentialArg *);
+double DehnenCoreSphericalPotentialDens(double ,double , double, double,
+					struct potentialArg *);
+
+//HomogeneousSpherePotential
+double HomogeneousSpherePotentialEval(double ,double , double, double,
+				      struct potentialArg *);
+double HomogeneousSpherePotentialRforce(double ,double , double, double,
+					struct potentialArg *);
+double HomogeneousSpherePotentialPlanarRforce(double ,double, double,
+					      struct potentialArg *);
+double HomogeneousSpherePotentialzforce(double,double,double,double,
+					struct potentialArg *);
+double HomogeneousSpherePotentialPlanarR2deriv(double ,double, double,
+					       struct potentialArg *);
+double HomogeneousSpherePotentialDens(double ,double , double, double,
+				      struct potentialArg *);
+
 //////////////////////////////// WRAPPERS /////////////////////////////////////
 //DehnenSmoothWrapperPotential
 double DehnenSmoothWrapperPotentialEval(double,double,double,double,
@@ -536,6 +654,16 @@ double MovingObjectPotentialPlanarRforce(double,double,double,
 					struct potentialArg *);
 double MovingObjectPotentialPlanarphiforce(double,double,double,
 					    struct potentialArg *);
+//ChandrasekharDynamicalFrictionForce, takes vR,vT,vZ
+double ChandrasekharDynamicalFrictionForceRforce(double,double,double,double,
+						 struct potentialArg *,
+						 double,double,double);
+double ChandrasekharDynamicalFrictionForcephiforce(double,double,double,double,
+						   struct potentialArg *,
+						   double,double,double);
+double ChandrasekharDynamicalFrictionForcezforce(double,double,double,double,
+						 struct potentialArg *,
+						 double,double,double);
 #ifdef __cplusplus
 }
 #endif
