@@ -146,7 +146,12 @@ void leapfrog(void (*func)(double t, double *q, double *a,
     if ( interrupted ) {
       *err= -10;
       interrupted= 0; // need to reset, bc library and vars stay in memory
+#ifdef USING_COVERAGE
+      __gcov_flush();
+#endif
+// LCOV_EXCL_START
       break;
+// LCOV_EXCL_STOP
     }
     //drift half
     leapfrog_leapq(dim,qo,po,dt/2.,q12);
@@ -266,7 +271,12 @@ void symplec4(void (*func)(double t, double *q, double *a,
     if ( interrupted ) {
       *err= -10;
       interrupted= 0; // need to reset, bc library and vars stay in memory
+#ifdef USING_COVERAGE
+      __gcov_flush();
+#endif
+// LCOV_EXCL_START
       break;
+// LCOV_EXCL_STOP
     }
     //drift for c1*dt
     leapfrog_leapq(dim,qo,po,c1*dt,q12);
@@ -421,7 +431,12 @@ void symplec6(void (*func)(double t, double *q, double *a,
     if ( interrupted ) {
       *err= -10;
       interrupted= 0; // need to reset, bc library and vars stay in memory
+#ifdef USING_COVERAGE
+      __gcov_flush();
+#endif
+// LCOV_EXCL_START
       break;
+// LCOV_EXCL_STOP
     }
     //drift for c1*dt
     leapfrog_leapq(dim,qo,po,c1*dt,q12);
