@@ -337,7 +337,12 @@ void dop853(void(*func)(double t, double *q, double *a, int nargs, struct potent
 		if (interrupted) {
 			*err_ = -10;
 			interrupted = 0; // need to reset, bc library and vars stay in memory
+#ifdef USING_COVERAGE
+			__gcov_flush();
+#endif
+// LCOV_EXCL_START
 			break;
+// LCOV_EXCL_STOP
 		}
 		h = pos_neg * max(fabs(h), 1e3 * uround);  // keep time step not too small
 
@@ -508,4 +513,4 @@ void dop853(void(*func)(double t, double *q, double *a, int nargs, struct potent
 	free(rcont2);
 	free(rcont1);
 	//We're done
-}
\ No newline at end of file
+}
